package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.DoumuProductInfo;
import com.ruoyi.system.domain.vo.DoumuProductInfoVo;

/**
 * 痘姆古陶信息Service接口
 *
 * @author boman
 * @date 2024-01-16
 */
public interface IDoumuProductInfoService
{
    /**
     * 查询痘姆古陶信息
     *
     * @param productId 痘姆古陶信息主键
     * @return 痘姆古陶信息
     */
    public DoumuProductInfo selectDoumuProductInfoByProductId(Long productId);

    /**
     * 查询痘姆古陶信息列表
     *
     * @param doumuProductInfo 痘姆古陶信息
     * @return 痘姆古陶信息集合
     */
    public List<DoumuProductInfo> selectDoumuProductInfoList(DoumuProductInfo doumuProductInfo);

    /**
     * 新增痘姆古陶信息
     *
     * @param doumuProductInfo 痘姆古陶信息
     * @return 结果
     */
    public int insertDoumuProductInfo(DoumuProductInfo doumuProductInfo);

    /**
     * 修改痘姆古陶信息
     *
     * @param doumuProductInfo 痘姆古陶信息
     * @return 结果
     */
    public int updateDoumuProductInfo(DoumuProductInfo doumuProductInfo);

    /**
     * 批量删除痘姆古陶信息
     *
     * @param productIds 需要删除的痘姆古陶信息主键集合
     * @return 结果
     */
    public int deleteDoumuProductInfoByProductIds(Long[] productIds);

    /**
     * 删除痘姆古陶信息信息
     *
     * @param productId 痘姆古陶信息主键
     * @return 结果
     */
    public int deleteDoumuProductInfoByProductId(Long productId);

    int editFlow(DoumuProductInfoVo doumuProductInfoVo);

    AjaxResult link(String dateType);

    AjaxResult monthLink();
}
